@@ -18,11 +18,11 @@
 ;;; along with Guile-Git.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (tests config)
+  #:use-module (git)
+  #:use-module (git configuration)
+  #:use-module (tests helpers)
   #:use-module (srfi srfi-64))
 
-(use-modules (tests helpers))
-(use-modules (git))
-
 (test-begin "config")
 
 (libgit2-init!)
@@ -105,7 +105,19 @@
                     '("guix.test.string"
                       "guix.test.int32"
                       "guix.test.int64"
-                      "guix.test.boolean"))))))))
+                      "guix.test.boolean")))))))
+
+  (unless %have-config-entry-backend-type? (test-skip 1))
+  (test-equal "backend-type & origin-path"
+    (list 'file
+          (canonicalize-path (in-vicinity directory "config")))
+    (let* ((repository (repository-open directory))
+           (config     (repository-config repository))
+           (entry      (config-get-entry config "guix.test.string"))
+           (type       (config-entry-backend-type entry))
+           (path       (config-entry-origin-path entry)))
+      (repository-close! repository)
+      (list type path))))
 
 (libgit2-shutdown!)
 
