@@ -20,7 +20,8 @@
 ;;; along with Guile-Git.  If not, see <http://www.gnu.org/licenses/>.
 
 (define-module (tests remote)
-  #:use-module (srfi srfi-64))
+  #:use-module (srfi srfi-64)
+  #:use-module (ice-9 match))
 
 (use-modules (tests helpers))
 (use-modules (git)
@@ -93,6 +94,44 @@
 	    (lambda (x y)
 	      (string<? (list-ref x 3) (list-ref y 3)))))))
 
+(with-repository "simple" remote-directory
+  (let* ((git-directory (string-append (canonicalize-path remote-directory)
+                                       "/.git/"))
+         (pull-base "refs/pull")
+         (symref "refs/pull/1")
+         ;; Some commit in the remote.
+         (symref-commit "b70d89182da3b2019c3fd6755c794ee65921b4a8")
+         (expected-result (list GIT_ENOTFOUND
+                                GITERR_ODB
+                                symref-commit)))
+    (mkdir (string-append git-directory
+                          pull-base))
+    ;; Create a symbolic reference in the remote.
+    (call-with-output-file (string-append git-directory
+                                          symref)
+      (lambda (port)
+        (display symref-commit port)))
+    ;; Actual test.
+    (test-equal "remote-fetch with refspecs"
+      expected-result
+      (let* ((repository (repository-init (tmpnam))) ; Start with an empty repository.
+             (oid (string->oid symref-commit))
+             (error (catch 'git-error
+                      (lambda ()
+                        (object-lookup repository oid))
+                      (lambda (key err)
+                        (list (git-error-code err)
+                              (git-error-class err)))))
+             (remote (remote-create-anonymous repository
+                                              (string-append "file://"
+                                                             (canonicalize-path remote-directory)))))
+        (remote-fetch remote #:refspecs (list symref))
+        (object-lookup repository oid)
+        (append error
+                (list
+                 (oid->string
+                  (object-id (object-lookup repository oid)))))))))
+
 (libgit2-shutdown!)
 
 (test-end)
